package WebGUI::i18n::German::Asset_Product;
use utf8;
our $I18N = {
  10 => {
    'lastUpdated' => '1226017303',
    'message' => 'Preis'
  },
  '10 description' => {
    'lastUpdated' => '1226017314',
    'message' => 'Der Preis dieser Variante'
  },
  11 => {
    'lastUpdated' => undef,
    'message' => ''
  },
  '11 description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  13 => {
    'lastUpdated' => '1226017335',
    'message' => 'Prospekt'
  },
  '13 description' => {
    'lastUpdated' => '1226017364',
    'message' => 'Der Prospekt für dieses Produkt'
  },
  14 => {
    'lastUpdated' => '1226017377',
    'message' => 'Handbuch'
  },
  '14 description' => {
    'lastUpdated' => '1226017391',
    'message' => 'Das Handbuch für dieses Produkt'
  },
  15 => {
    'lastUpdated' => '1226017399',
    'message' => 'Garantie'
  },
  '15 description' => {
    'lastUpdated' => '1226017417',
    'message' => 'Die Garantie für dieses Produkt'
  },
  16 => {
    'lastUpdated' => '1240737560',
    'message' => 'Accessoire hinzufügen'
  },
  17 => {
    'lastUpdated' => '1240737616',
    'message' => 'Accessoire'
  },
  '17 description' => {
    'lastUpdated' => '1241190768',
    'message' => 'Wählen Sie ein Produkt aus der bereits eingegebenen Artikelliste aus.'
  },
  18 => {
    'lastUpdated' => '1240739306',
    'message' => 'Weiteres Accessoire hinzufügen?'
  },
  '18 description' => {
    'lastUpdated' => '1243496345',
    'message' => 'Wählen Sie "ja", wenn Sie ein weiteres Accessoire hinzufügen möchten.'
  },
  19 => {
    'lastUpdated' => '1226017464',
    'message' => 'Verwandtes Produkt hinzufügen'
  },
  2 => {
    'lastUpdated' => '1240737603',
    'message' => 'Möchten Sie die Verbindung zu diesem Accessoire wirklich löschen?'
  },
  20 => {
    'lastUpdated' => '1240737670',
    'message' => 'verwandtes Produkt'
  },
  '20 description' => {
    'lastUpdated' => '1243495719',
    'message' => 'Wählen Sie aus der Liste der Produkte, die Sie bereits eingegeben haben.'
  },
  21 => {
    'lastUpdated' => '1240739865',
    'message' => 'Weiteres verwandtes Produkt hinzufügen?'
  },
  '21 description' => {
    'lastUpdated' => '1248720886',
    'message' => 'Selektiere "Ja", wenn Sie ein vergleichbares Produkt hinzufügen möchten.'
  },
  22 => {
    'lastUpdated' => '1240739771',
    'message' => 'Merkmal bearbeiten'
  },
  23 => {
    'lastUpdated' => '1240737795',
    'message' => 'Merkmal'
  },
  '23 description' => {
    'lastUpdated' => '1251506696',
    'message' => 'Sie können ein neues Merkmal angeben oder eines auswählen, das bereits für ein anderes Produkt definiert wurde.'
  },
  24 => {
    'lastUpdated' => '1240738853',
    'message' => 'Weiteres Merkmal hinzufügen?'
  },
  '24 description' => {
    'lastUpdated' => '1251506660',
    'message' => 'Wenn Sie ein weiteres Merkmal ergänzen möchten, wählen Sie "Ja"'
  },
  25 => {
    'lastUpdated' => '1240739847',
    'message' => 'Spezification bearbeiten'
  },
  26 => {
    'lastUpdated' => '1240738879',
    'message' => 'Label'
  },
  '26 description' => {
    'lastUpdated' => '1251506782',
    'message' => 'Die Art der Eigenschaft. Z.B: Höhe, Gewicht, Farbe. Sie können eine auswählen, die bereits für ein anderes Produkt definiert wurde oder eine neue eingeben. '
  },
  27 => {
    'lastUpdated' => '1251506795',
    'message' => 'Eigenschaft'
  },
  '27 description' => {
    'lastUpdated' => '1251506931',
    'message' => 'Der aktuelle Wert der Eigenschaft. Wenn Sie bspw. Höhe als Name auswählen, geben sie einen Zahlenwert, z.B. "18" ein.'
  },
  28 => {
    'lastUpdated' => '1251506810',
    'message' => 'Weitere Eigenschaft hinzufügen?'
  },
  '28 description' => {
    'lastUpdated' => '1251506982',
    'message' => 'Wenn Sie eine weitere Eigenschaft hinzufügen möchten, wählen Sie "Ja".'
  },
  29 => {
    'lastUpdated' => '1240738921',
    'message' => 'Einheiten'
  },
  '29 description' => {
    'lastUpdated' => '1251507049',
    'message' => 'Die Einheit der Maßangabe für diese Eigenschaft. Bei "Höhe" geben sie bspw. "Meter" an'
  },
  3 => {
    'lastUpdated' => '1226017499',
    'message' => 'Wollen Sie diese Eigenschaft wirklich löschen?'
  },
  30 => {
    'lastUpdated' => '1226017508',
    'message' => 'Eigenschaften'
  },
  31 => {
    'lastUpdated' => '1251506826',
    'message' => 'Eigenschaften'
  },
  32 => {
    'lastUpdated' => '1226017530',
    'message' => 'Zubehör'
  },
  33 => {
    'lastUpdated' => '1240738935',
    'message' => 'Verwandte Produkte'
  },
  34 => {
    'lastUpdated' => '1240739787',
    'message' => 'Merkmal hinzufügen'
  },
  35 => {
    'lastUpdated' => '1240739821',
    'message' => 'Spezifikation hinzufügen'
  },
  36 => {
    'lastUpdated' => '1240738991',
    'message' => 'Accessoire hinzufügen'
  },
  37 => {
    'lastUpdated' => '1240739005',
    'message' => 'Verwandtes Produkt hinzufügen'
  },
  4 => {
    'lastUpdated' => '1240739054',
    'message' => 'Möchten Sie die Verbindung zu diesem verwandten Produkt wirklich löschen?'
  },
  48 => {
    'lastUpdated' => '1240739093',
    'message' => 'Möchten Sie diesen Vorteil wirklich löschen?'
  },
  5 => {
    'lastUpdated' => '1240739117',
    'message' => 'Möchten Sie diese Spezifikation wirklich löschen?'
  },
  51 => {
    'lastUpdated' => '1240739126',
    'message' => 'Vorteil'
  },
  '51 description' => {
    'lastUpdated' => '1241190882',
    'message' => 'Sie können einen weiteren Vorteil zu diesem Produkt eingeben oder einen bereits vorhandenen Vorteil auswählen.'
  },
  52 => {
    'lastUpdated' => '1240739142',
    'message' => 'Weiterer Vorteil hinzufügen?'
  },
  '52 description' => {
    'lastUpdated' => '1243495782',
    'message' => 'Wählen Sie "ja", wenn Sie einen weiteren Vorteil hinzufügen möchten.'
  },
  53 => {
    'lastUpdated' => '1240739154',
    'message' => 'Vorteil bearbeiten'
  },
  54 => {
    'lastUpdated' => '1240739163',
    'message' => 'Vorteile'
  },
  55 => {
    'lastUpdated' => '1240739175',
    'message' => 'Vorteil hinzufügen'
  },
  56 => {
    'lastUpdated' => '1240739196',
    'message' => 'Produktvorlage hinzufügen'
  },
  57 => {
    'lastUpdated' => '1251507147',
    'message' => 'Sind Sie sicher, dass Sie dieses Template löschen möchten und alle Produkte, die es nutzen auf das Standardtemplate zu setzen.'
  },
  58 => {
    'lastUpdated' => '1240739219',
    'message' => 'Produktvorlage bearbeiten'
  },
  59 => {
    'lastUpdated' => '1240739227',
    'message' => 'Name'
  },
  6 => {
    'lastUpdated' => '1240739239',
    'message' => 'Produkt bearbeiten'
  },
  60 => {
    'lastUpdated' => '1240739248',
    'message' => 'Vorlage'
  },
  62 => {
    'lastUpdated' => '1240739259',
    'message' => 'Produktvorlage'
  },
  '62 description' => {
    'lastUpdated' => '1251507165',
    'message' => 'Wählen Sie ein Layout für dieses Produkt'
  },
  7 => {
    'lastUpdated' => '1240739270',
    'message' => 'Produktbild 1'
  },
  '7 description' => {
    'lastUpdated' => '1251507178',
    'message' => 'Ein Bild für dieses Produkt'
  },
  8 => {
    'lastUpdated' => '1240739282',
    'message' => 'Produktbild 2'
  },
  '8 description' => {
    'lastUpdated' => '1251507197',
    'message' => 'Ein Bild für dieses Produkt '
  },
  9 => {
    'lastUpdated' => '1240736009',
    'message' => 'Produkt Bild 3'
  },
  '9 description' => {
    'lastUpdated' => '1251507215',
    'message' => 'Ein Bild für dieses Produkt'
  },
  'Controls' => {
    'lastUpdated' => '1251507232',
    'message' => 'Kontrollen'
  },
  'Lost' => {
    'lastUpdated' => '1301988746',
    'message' => 'Asset verloren'
  },
  'accessory.controls' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'accessory.title' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'accessory.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'accessory_controls' => {
    'lastUpdated' => '1251589610',
    'message' => 'WebGUI-Verwaltungswerkzeuge für dieses Asset'
  },
  'accessory_loop' => {
    'lastUpdated' => '1251589661',
    'message' => 'Diese Schleife enthält das Zubehör, das diesem Produkt zugeordnet ist.'
  },
  'accessory_title' => {
    'lastUpdated' => '1240737263',
    'message' => 'Accessoire'
  },
  'accessory_url' => {
    'lastUpdated' => '1240737282',
    'message' => 'URL zum Accessoire'
  },
  'add a variant' => {
    'lastUpdated' => '1240737298',
    'message' => 'Variante hinzufügen'
  },
  'add another variant' => {
    'lastUpdated' => '1240737315',
    'message' => 'Weitere Variante hinzufügen?'
  },
  'add another variant description' => {
    'lastUpdated' => '1240737845',
    'message' => 'Klicke "Ja", wenn Sie eine weitere Varinate hinzufügen möchten.'
  },
  'add to cart' => {
    'lastUpdated' => '1240736038',
    'message' => 'In den Warenkorb legen'
  },
  'add variant' => {
    'lastUpdated' => '1240737346',
    'message' => 'Variante hinzufügen'
  },
  'addRelatedProduct.label' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'addRelatedProduct.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'addRelatedProduct_label' => {
    'lastUpdated' => '1240737886',
    'message' => 'Verwandtes Produkt hinzufügen'
  },
  'addRelatedProduct_url' => {
    'lastUpdated' => '1251507621',
    'message' => 'URL um ein verwandtes Produkt hinzuzufügen'
  },
  'addaccessory.label' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'addaccessory.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'addaccessory_label' => {
    'lastUpdated' => '1240737914',
    'message' => 'Accessoire hinzufügen'
  },
  'addaccessory_url' => {
    'lastUpdated' => '1251507651',
    'message' => 'URL um ein Zubehör-Produkt hinzuzufügen'
  },
  'addbenefit.label' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'addbenefit.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'addbenefit_label' => {
    'lastUpdated' => '1240737363',
    'message' => 'Vorteil hinzufügen'
  },
  'addbenefit_url' => {
    'lastUpdated' => '1251507678',
    'message' => 'URL, um eine Produktzugabe hinzuzufügen'
  },
  'addfeature.label' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'addfeature.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'addfeature_label' => {
    'lastUpdated' => '1240736947',
    'message' => 'Merkmal hinzufügen'
  },
  'addfeature_url' => {
    'lastUpdated' => '1240737197',
    'message' => 'URL zum Hinzufügen eines Produktvorteils'
  },
  'addspecification.label' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'addspecification.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'addspecification_label' => {
    'lastUpdated' => '1240736993',
    'message' => 'Spezifikation hinzufügen'
  },
  'addspecification_url' => {
    'lastUpdated' => '1251507708',
    'message' => 'URL um eine Produktspezifikation hinzuzufügen'
  },
  'addvariant_label' => {
    'lastUpdated' => '1240736782',
    'message' => 'Variante hinzufügen'
  },
  'addvariant_url' => {
    'lastUpdated' => '1240737155',
    'message' => 'URL zum Hinzufügen einer Produktvariante'
  },
  'assetName' => {
    'lastUpdated' => '1157856343',
    'message' => 'Produkt'
  },
  'benefit.benefit' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'benefit.controls' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'benefit_benefit' => {
    'lastUpdated' => '1240737112',
    'message' => 'Text zum Produktvorteil'
  },
  'benefit_controls' => {
    'lastUpdated' => '1251590010',
    'message' => 'Die WebGUI Verwaltungswerkzeuge für diesen Vorteil'
  },
  'benefit_loop' => {
    'lastUpdated' => '1251589729',
    'message' => 'Diese Schleife enthält die Vorteile für dieses Produkt'
  },
  'brochure' => {
    'lastUpdated' => '1240739335',
    'message' => 'ID Produktprospekt'
  },
  'brochure.icon' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'brochure.label' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'brochure.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'brochure_icon' => {
    'lastUpdated' => '1241190918',
    'message' => 'URL zum Prospekticon'
  },
  'brochure_label' => {
    'lastUpdated' => '1240737415',
    'message' => 'URL Broschüre'
  },
  'brochure_url' => {
    'lastUpdated' => '1251507749',
    'message' => 'URL um die Brochure herunterzuladen'
  },
  'buy_form_button' => {
    'lastUpdated' => '1240737014',
    'message' => 'Kaufen'
  },
  'buy_form_footer' => {
    'lastUpdated' => '1240737071',
    'message' => 'Variante in den Warenkorb legen'
  },
  'buy_form_header' => {
    'lastUpdated' => '1251589794',
    'message' => 'HTML-Code für den Formularanfang um Varianten in den Warenkorb zu legen'
  },
  'buy_form_options' => {
    'lastUpdated' => '1251590524',
    'message' => 'Eine Auswahlliste mit allen verfügbaren Varianten dieses Produkts. Nur Varianten mit einer Anzahl größer Null werden aufgeführt.'
  },
  'cache timeout' => {
    'lastUpdated' => '1251590471',
    'message' => 'Cache Timeout'
  },
  'cache timeout help' => {
    'lastUpdated' => '1251590402',
    'message' => 'Da alle Nutzer dieses Asset auf die gleiche Art und Weise sehen, kann es für eine lange Zeit gecachet werden, um die Geschwindigkeit zu steigern. Wie lange soll es gecachet werden?'
  },
  'cacheTimeout' => {
    'lastUpdated' => '1251590322',
    'message' => 'Die Anzahl Sekunden, die die Ausgabe dieses Assets gecachet wird.'
  },
  'canEdit' => {
    'lastUpdated' => '1251590275',
    'message' => 'Ein boolscher Wert, der wahr ist, wenn der Nutzer dieses Produkt bearbeiten darf.'
  },
  'continueShoppingUrl' => {
    'lastUpdated' => '1251590460',
    'message' => 'Ein URL, um das Produkt zurückzusetzen, damit der Nutzer seinen Einkauf fortsetzen kann.'
  },
  'default thank you message' => {
    'lastUpdated' => '1241160442',
    'message' => 'Herzlichen Dank für Ihren Einkauf!'
  },
  'delete variant confirm' => {
    'lastUpdated' => '1251590420',
    'message' => 'Sind Sie sicher, dass Sie diese Variante löschen möchten?'
  },
  'deleteImage' => {
    'lastUpdated' => '1251507777',
    'message' => 'Angehängte Datei löschen'
  },
  'feature.controls' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'feature.feature' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'feature_controls' => {
    'lastUpdated' => '1251590047',
    'message' => 'Die WebGUI Verwaltungswerkzeuge für dieses Merkmal'
  },
  'feature_feature' => {
    'lastUpdated' => '1240736913',
    'message' => 'Der Text zum Merkmal'
  },
  'feature_loop' => {
    'lastUpdated' => '1251590075',
    'message' => 'Schleife, die alle Merkmale enthält, die diesem Produkt zugeordnet sind.'
  },
  'hasAddedToCart' => {
    'lastUpdated' => '1251590141',
    'message' => 'Eine Bedingung, die anzeigt, ob der Nutzer das Produkt in seinen Warenkorb gelegt hat, um ihm eine Dankesnachricht anzuzeigen.'
  },
  'image1' => {
    'lastUpdated' => '1240739396',
    'message' => 'ID Produktbild 1'
  },
  'image2' => {
    'lastUpdated' => '1241190938',
    'message' => 'ID Produktbild 2'
  },
  'image3' => {
    'lastUpdated' => '1241190952',
    'message' => 'ID Produktbild 3'
  },
  'in_stock' => {
    'lastUpdated' => '1240739554',
    'message' => 'Produktvarianten verfügbar'
  },
  'isShippingRequired' => {
    'lastUpdated' => '1241190971',
    'message' => 'Is Versand erforderlich?'
  },
  'isShippingRequired help' => {
    'lastUpdated' => '1241191016',
    'message' => 'Dieses legt fest, ob Versandkosten berechnet werden.'
  },
  'manual' => {
    'lastUpdated' => '1240739502',
    'message' => 'ID Produkthandbuch'
  },
  'manual.icon' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'manual.label' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'manual.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'manual_icon' => {
    'lastUpdated' => '1251589815',
    'message' => 'URL zum Icon für das Handbuch'
  },
  'manual_label' => {
    'lastUpdated' => '1240739456',
    'message' => 'URL Handbuch'
  },
  'manual_url' => {
    'lastUpdated' => '1251589830',
    'message' => 'URL zum Download des Handbuches'
  },
  'no_stock_message' => {
    'lastUpdated' => '1240736641',
    'message' => 'Eine internationalisierte Nachtricht, die aussagt, dass zu diesem Produkt keine Varianten verfügbar sind. '
  },
  'options' => {
    'lastUpdated' => '1240739475',
    'message' => 'Optionen'
  },
  'other products' => {
    'lastUpdated' => '1240739408',
    'message' => 'Weitere Produkte'
  },
  'out of stock' => {
    'lastUpdated' => '1240736694',
    'message' => 'Nicht verfügbar'
  },
  'price' => {
    'lastUpdated' => '1240736314',
    'message' => 'Artikelpreis'
  },
  'product asset template variables body' => {
    'lastUpdated' => '1170408745',
    'message' => 'Jedes Asset bietet ihren Templates einen Satz an Variablen, die auf den Asset Eigenschaften basieren. Einige dieser Variablen können nützlich sein, andere nicht.'
  },
  'product asset template variables title' => {
    'lastUpdated' => '1170408760',
    'message' => 'Produkt Asset Template Variablen<br />'
  },
  'productNumber' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'quantity' => {
    'lastUpdated' => '1226017598',
    'message' => 'Menge'
  },
  'quantity description' => {
    'lastUpdated' => '1240738016',
    'message' => 'Wieviele Einheiten dieser Variante sind verfügbar?'
  },
  'relatedproduct.controls' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'relatedproduct.loop' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'relatedproduct.title' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'relatedproduct.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'relatedproduct_controls' => {
    'lastUpdated' => '1251590183',
    'message' => 'Die WebGUI Verwaltungswerkzeuge für dieses verwandte Produkt'
  },
  'relatedproduct_loop' => {
    'lastUpdated' => '1251590213',
    'message' => 'Eine Schleife, die alle verwandten Produkte enthält, die diesem Produkt zugeordnet sind.'
  },
  'relatedproduct_title' => {
    'lastUpdated' => '1240737984',
    'message' => 'Verwandtes Produkt'
  },
  'relatedproduct_url' => {
    'lastUpdated' => '1251590228',
    'message' => 'URL zum verwandten Produkt'
  },
  'shortdesc' => {
    'lastUpdated' => '1240736143',
    'message' => 'Kurzbeschreibung'
  },
  'shortdesc description' => {
    'lastUpdated' => '1251589921',
    'message' => 'Die Kurzbeschreibung wird dem Nutzer angezeigt, damit er diese Variante des Produkts kaufen kann. Die Länge der Kurzbeschreibung ist auf 30 Zeichen begrenzt.'
  },
  'specification.controls' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'specification.label' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'specification.specification' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'specification.units' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'specification_controls' => {
    'lastUpdated' => '1251590162',
    'message' => 'Die WebGUI Verwaltungswerkzeuge für diese Spezifikation'
  },
  'specification_label' => {
    'lastUpdated' => '1240736379',
    'message' => 'Label für diese Spezifikation, z.B.: Höhe'
  },
  'specification_loop' => {
    'lastUpdated' => '1251589947',
    'message' => 'Liste der Spezifikationen, die diesem Produkt zugeordnet sind.'
  },
  'specification_specification' => {
    'lastUpdated' => '1251589961',
    'message' => 'Text für die Spezifikation'
  },
  'specification_units' => {
    'lastUpdated' => '1240738103',
    'message' => 'Die Einheit zu dieser Spezifikation, z.B. m (meter)'
  },
  'specs' => {
    'lastUpdated' => '1226017614',
    'message' => 'Spez.'
  },
  'templateId' => {
    'lastUpdated' => '1251507578',
    'message' => 'Die Template-ID für die Assetanzeige'
  },
  'thank you message' => {
    'lastUpdated' => '1240736206',
    'message' => '"Danke"-Nachricht'
  },
  'thank you message help' => {
    'lastUpdated' => '1251507549',
    'message' => 'Verfassen Sie einen Danke-Text, dafür dass er etwas auf Ihrer Site gekauft hat.'
  },
  'thumbnail1' => {
    'lastUpdated' => '1251507483',
    'message' => 'URL zum Vorschaubild des ersten Produktbildes '
  },
  'thumbnail2' => {
    'lastUpdated' => '1251507472',
    'message' => 'URL zum Vorschaubild des zweiten Produktbildes '
  },
  'thumbnail3' => {
    'lastUpdated' => '1251507461',
    'message' => 'URL zum Vorschaubild des dritten Produktbildes '
  },
  'variant sku' => {
    'lastUpdated' => '1240736166',
    'message' => 'Artikelnummer'
  },
  'variant sku description' => {
    'lastUpdated' => '1240738202',
    'message' => 'ID für diese Produktvariante. Diese sollte die ID in Ihrer Lagersoftware entsprechen, damit eine Synchronisation oder Abgleich möglich ist. '
  },
  'variant_controls' => {
    'lastUpdated' => '1251507420',
    'message' => 'Die Icon-Werkzeugleiste für Bearbeiten, Löschen, Aufnehmen dieser Variante'
  },
  'variant_id' => {
    'lastUpdated' => '1240738253',
    'message' => 'Die ID für diese Variante'
  },
  'variant_loop' => {
    'lastUpdated' => '1251507373',
    'message' => 'Schleife, die alle Varianten zu diesem Produkt enthält'
  },
  'variant_price' => {
    'lastUpdated' => '1240738228',
    'message' => 'Preis der Variante'
  },
  'variant_quantity' => {
    'lastUpdated' => '1251507346',
    'message' => 'Anzahl dieser Variante'
  },
  'variant_sku' => {
    'lastUpdated' => '1226017631',
    'message' => 'Die Artikelnummer für diese Variante'
  },
  'variant_title' => {
    'lastUpdated' => '1226017780',
    'message' => 'Titel oder Kurzbeschreibung für diese Variante'
  },
  'variant_weight' => {
    'lastUpdated' => '1226017798',
    'message' => 'Gewicht dieser Variante'
  },
  'variants' => {
    'lastUpdated' => '1226017582',
    'message' => 'Varianten'
  },
  'warranty' => {
    'lastUpdated' => '1240736272',
    'message' => 'Garantie-ID'
  },
  'warranty.icon' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'warranty.label' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'warranty.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'warranty_icon' => {
    'lastUpdated' => '1251507332',
    'message' => 'URL zum Icon für die Garantiebstimmungen'
  },
  'warranty_label' => {
    'lastUpdated' => '1240736412',
    'message' => 'URL Garantie'
  },
  'warranty_url' => {
    'lastUpdated' => '1251507313',
    'message' => 'URL zum Download der Garantiebestimmungen'
  },
  'weight' => {
    'lastUpdated' => '1226017559',
    'message' => 'Gewicht'
  },
  'weight description' => {
    'lastUpdated' => '1251507277',
    'message' => 'Das Standardgewicht dieser Variante'
  }
}
;

1;
